import request from "@/utils/request";

export function getList(data) {
  return request({
    url: '/datasources/datasources/all',
    method: 'post',
    data
  })
}

/**
 * 连接数据源
 * @param data
 * @returns {*}
 */
export function connectDataSources(data) {
  return request({
    url: '/datasources/datasources/connectDataSources',
    method: 'post',
    data
  })
}

/**
 * 同步数据源
 * @param data
 * @returns {*}
 */
export function syncAssetStructure(data) {
  return request({
    url: '/datasources/datasources/syncAssetStructure',
    method: 'post',
    data
  })
}


/**
 * 添加数据源
 * @param data
 * @returns {*}
 */
export function addDataSources(data) {
  return request({
    url: '/datasources/datasources/addDataSources',
    method: 'post',
    data
  })
}

/**
 * 修改数据源
 * @param data
 * @returns {AxiosPromise}
 */
export function updateDataSources(data) {
  return request({
    url: '/datasources/datasources/updateDataSources',
    method: 'put',
    data
  })
}
/**
 * 修改数据源
 * @param id
 * @returns {AxiosPromise}
 */
export function deleteDataSourcesById(id) {
  return request({
    url: `/datasources/datasources/`+id,
    method: 'delete',
  })
}
export function getDataSourcesById(id) {
  return request({
    url: '/datasources/datasources/' + id,
    method: 'get'
  })
}


/**
 * 查询数据库和相关联表
 * @returns {*}
 */
export function findByTableName() {
  return request({
    url: '/datasources/tableInfo',
    method: 'get',
  })
}



export function findAsset() {
  return request({
    url: '/datasources/tableInfo/findAsset',
    method: 'get',
  })
}

/**
 * 根据id查询表结构
 * @returns {AxiosPromise}
 */
export function findStructureByTableId(id) {
  return request({
    url: '/datasources/structure/findStructureByTableId/'+id,
    method: 'get',
  })
}
/**
 * 根据id查询表结构
 * @returns {AxiosPromise}
 */
export function findTableName(id) {
  return request({
    url: '/datasources/tableInfo/findTableName',
    method: 'post',
    params:{id:id}
  })
}

/**
 * 根据数据库id,和表名查询到值
 * @param id
 * @returns {*}
 */
export function findTableValueByTableName(basicId,tableName) {
  return request({
    url: '/datasources/dataValue/findTableValueByTableName',
    method: 'post',
    params:{basicId:basicId,tableName:tableName}
  })
}

// export function findTableValueContributionRule(basicId,tableId) {
//   return request({
//     url: '/datasources/dataValue/findTableValueContributionRule',
//     method: 'post',
//     params:{basicId:basicId,tableId:tableId}
//   })
// }
